Array

Struct Array 

pub struct Array<S, V, T, L = <V as Vector<S>>::DefaultLayout>
where S: Integer, V: Vector<S>, L: Layout<S, V>,
{ /* private fields */ }
An array indexed by points in a bounding box.

Implementations

Source

impl<S, V, T> Array<S, V, T, <V as Vector<S>>::DefaultLayout>
where S: Integer, V: Vector<S>,

pub fn new(bbox: BBox<S, V>, d: T) -> Self
where T: Clone, usize: TryFrom<S>, <usize as TryFrom<S>>::Error: Debug, <S as TryFrom<usize>>::Error: Debug,

Creates a new array with the given bounding box that is filled with copies of a given element.

pub fn with<F>(bbox: BBox<S, V>, f: F) -> Self
where F: FnMut(Point<S, V>) -> T, usize: TryFrom<S>, <usize as TryFrom<S>>::Error: Debug, <S as TryFrom<usize>>::Error: Debug,

Creates a new array with the given bounding box that is filled using a function which takes a location as input.

Source

impl<S, V, T, L> Array<S, V, T, L>
where S: Integer, V: Vector<S>, L: Layout<S, V>,

pub fn bbox(&self) -> BBox<S, V>

Returns the bounding box of the array.

pub fn bounds(&self) -> BBox<S, V>

👎Deprecated: Use bbox instead.

Returns the bounding box of the array.

pub fn get(&self, index: Point<S, V>) -> Option<&T>
where usize: TryFrom<S>, <usize as TryFrom<S>>::Error: Debug,

Returns a reference to the element at the index or None if the index is out of bounds.

pub fn get_mut(&mut self, index: Point<S, V>) -> Option<&mut T>
where usize: TryFrom<S>, <usize as TryFrom<S>>::Error: Debug,

Returns a reference to the element at the index or None if the index is out of bounds.

pub fn iter(&self) -> impl Iterator<Item = &T>
where usize: TryFrom<S>, <usize as TryFrom<S>>::Error: Debug,

Returns an iterator over the elements of the array.

Source

impl<S, T> Array<S, Vec2d<S>, T>
where S: Integer,

pub fn from_vec(v: Vec<Vec<T>>) -> Self
where T: Copy, <S as TryFrom<usize>>::Error: Debug, usize: TryFrom<S>, <usize as TryFrom<S>>::Error: Debug,

Creates a new array with the given bounds that is filled from a vector of vectors.