MatrixOps

Trait MatrixOps 

pub trait MatrixOps<S, RHS = Self, Output = Self>
where Self: Sized + Mul<RHS, Output = Output>,
{ }
Required arithmetic operations for matrices.

Must be in a separate trait to allow Self to be a reference type and the output the base type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'a, S: Integer> MatrixOps<S, &'a Matrix2d<S>, Matrix2d<S>> for &'a Matrix2d<S>

Source

impl<'a, S: Integer> MatrixOps<S, &'a Matrix2d<S>> for Matrix2d<S>

Source

impl<'a, S: Integer> MatrixOps<S, &'a Matrix3d<S>, Matrix3d<S>> for &'a Matrix3d<S>

Source

impl<'a, S: Integer> MatrixOps<S, &'a Matrix3d<S>> for Matrix3d<S>

Source

impl<'a, S: Integer> MatrixOps<S, &'a Matrix4d<S>, Matrix4d<S>> for &'a Matrix4d<S>

Source

impl<'a, S: Integer> MatrixOps<S, &'a Matrix4d<S>> for Matrix4d<S>

Source

impl<'a, S: Integer> MatrixOps<S, &'a Vec2d<S>, Vec2d<S>> for &'a Matrix2d<S>

Source

impl<'a, S: Integer> MatrixOps<S, &'a Vec2d<S>, Vec2d<S>> for Matrix2d<S>

Source

impl<'a, S: Integer> MatrixOps<S, &'a Vec3d<S>, Vec3d<S>> for &'a Matrix3d<S>

Source

impl<'a, S: Integer> MatrixOps<S, &'a Vec3d<S>, Vec3d<S>> for Matrix3d<S>

Source

impl<'a, S: Integer> MatrixOps<S, &'a Vec4d<S>, Vec4d<S>> for &'a Matrix4d<S>

Source

impl<'a, S: Integer> MatrixOps<S, &'a Vec4d<S>, Vec4d<S>> for Matrix4d<S>

Source

impl<'a, S: Integer> MatrixOps<S, Matrix2d<S>, Matrix2d<S>> for &'a Matrix2d<S>

Source

impl<'a, S: Integer> MatrixOps<S, Matrix3d<S>, Matrix3d<S>> for &'a Matrix3d<S>

Source

impl<'a, S: Integer> MatrixOps<S, Matrix4d<S>, Matrix4d<S>> for &'a Matrix4d<S>

Source

impl<'a, S: Integer> MatrixOps<S, Vec2d<S>, Vec2d<S>> for &'a Matrix2d<S>

Source

impl<'a, S: Integer> MatrixOps<S, Vec3d<S>, Vec3d<S>> for &'a Matrix3d<S>

Source

impl<'a, S: Integer> MatrixOps<S, Vec4d<S>, Vec4d<S>> for &'a Matrix4d<S>

Source

impl<S: Integer> MatrixOps<S, Vec2d<S>, Vec2d<S>> for Matrix2d<S>

Source

impl<S: Integer> MatrixOps<S, Vec3d<S>, Vec3d<S>> for Matrix3d<S>

Source

impl<S: Integer> MatrixOps<S, Vec4d<S>, Vec4d<S>> for Matrix4d<S>

Source

impl<S: Integer> MatrixOps<S> for Matrix2d<S>

Source

impl<S: Integer> MatrixOps<S> for Matrix3d<S>

Source

impl<S: Integer> MatrixOps<S> for Matrix4d<S>