pub struct Array<S, V, T, L = <V as Vector<S>>::DefaultLayout>{ /* private fields */ }Expand description
An array indexed by points in a bounding box.
Implementations
Sourceimpl<S, V, T> Array<S, V, T, <V as Vector<S>>::DefaultLayout>
impl<S, V, T> Array<S, V, T, <V as Vector<S>>::DefaultLayout>
Sourceimpl<S, V, T, L> Array<S, V, T, L>
impl<S, V, T, L> Array<S, V, T, L>
Sourcepub fn bounds(&self) -> BBox<S, V>
👎Deprecated: Use bbox instead.
pub fn bounds(&self) -> BBox<S, V>
bbox instead.Returns the bounding box of the array.
Sourcepub fn get(&self, index: Point<S, V>) -> Option<&T>
pub fn get(&self, index: Point<S, V>) -> Option<&T>
Returns a reference to the element at the index or None if the index is out of bounds.